import { BaseGameDataMessage, PlatformSpecificData } from "@skeldjs/protocol";
import { BasicEvent, EventEmitter, ExtractEventTypes } from "@skeldjs/events";
import { CustomNetworkTransform, CustomNetworkTransformEvents, PlayerControl, PlayerControlEvents, PlayerPhysics, PlayerPhysicsEvents } from "./objects";
import { Hostable } from "./Hostable";
import { PlayerJoinEvent, PlayerLeaveEvent, PlayerReadyEvent, PlayerSceneChangeEvent, PlayerSetHostEvent, PlayerSpawnEvent } from "./events";
import { NetworkableEvents } from "./Networkable";
import { PlayerInfo } from "./misc";
import { BaseRole } from "./roles";
export declare type PlayerDataEvents<RoomType extends Hostable = Hostable> = NetworkableEvents<RoomType> & PlayerControlEvents<RoomType> & PlayerPhysicsEvents<RoomType> & CustomNetworkTransformEvents<RoomType> & ExtractEventTypes<[
    PlayerReadyEvent<RoomType>,
    PlayerJoinEvent<RoomType>,
    PlayerLeaveEvent<RoomType>,
    PlayerSetHostEvent<RoomType>,
    PlayerSceneChangeEvent<RoomType>,
    PlayerSpawnEvent<RoomType>
]>;
/**
 * Represents the player of a client connected to the room.
 *
 * See {@link PlayerDataEvents} for events to listen to.
 */
export declare class PlayerData<RoomType extends Hostable = Hostable> extends EventEmitter<PlayerDataEvents<RoomType>> {
    /**
     * This player's server-unique client ID.
     */
    readonly clientId: number;
    /**
     * The player's login name, not necessarily the display name, see {@link PlayerInfo}.
     */
    readonly username: string;
    /**
     * The platform that the player is playing on.
     */
    readonly platform: PlatformSpecificData;
    /**
     * The level/rank of the player.
     */
    readonly playerLevel: number;
    /**
     * The player's innersloth friend code.
     */
    readonly friendCode: string;
    /**
     * The player's unique global UUID.
     */
    readonly puid: string;
    /**
     * The room that this player object belongs to.
     */
    room: RoomType;
    /**
     * Whether or not this player is readied up to start the game.
     */
    isReady: boolean;
    /**
     * Whether or not this player is in the game scene.
     */
    inScene: boolean;
    /**
     * The message stream to be sent on fixed update.
     */
    stream: BaseGameDataMessage[];
    /**
     * This player's player control component.
     */
    control: PlayerControl<RoomType> | undefined;
    /**
     * The actual instance of this player's role manager, see {@link PlayerInfo.roleType}
     * to know which role this is.
     */
    role?: BaseRole;
    private _playerInfoCachedPlayerId?;
    private _playerInfoCached?;
    constructor(room: RoomType, 
    /**
     * This player's server-unique client ID.
     */
    clientId: number, 
    /**
     * The player's login name, not necessarily the display name, see {@link PlayerInfo}.
     */
    username: string, 
    /**
     * The platform that the player is playing on.
     */
    platform?: PlatformSpecificData, 
    /**
     * The level/rank of the player.
     */
    playerLevel?: number, 
    /**
     * The player's innersloth friend code.
     */
    friendCode?: string, 
    /**
     * The player's unique global UUID.
     */
    puid?: string);
    emit<Event extends BasicEvent>(event: Event): Promise<Event>;
    /**
     * The player's physics component.
     */
    get physics(): PlayerPhysics<RoomType> | undefined;
    /**
     * The player's movement component.
     */
    get transform(): CustomNetworkTransform<RoomType> | undefined;
    /**
     * Whether or not this player is a fake player, as in they are entirely
     * client-side and have no real player behind them.
     */
    get isFakePlayer(): boolean | undefined;
    /**
     * The player's game information, such as dead/impostor/disconnected states,
     * hats, names, pets, etc.
     */
    get playerInfo(): PlayerInfo | undefined;
    /**
     * Shorthand for `player.playerInfo.defaultOutfit.name`.
     *
     * This will return the player's name as it appears in-game, not including
     * the name of the player that they might have shapeshifted into.
     */
    get playerName(): string | undefined;
    /**
     * The room-unique player ID of the player.
     */
    get playerId(): number | undefined;
    /**
     * Whether or not the player has fully spawned.
     */
    get hasSpawned(): boolean;
    /**
     * Whether or not the player is the host of the room they belong in.
     */
    get isHost(): boolean;
    /**
     * Whether or not the player is the current client's player.
     */
    get isMe(): boolean;
    /**
     * Mark as readied up to start the game.
     */
    setReady(): Promise<void>;
    /**
     * Despawn all components on the player,
     */
    destroy(): void;
}
//# sourceMappingURL=PlayerData.d.ts.map